KeyboardTheme class

Constructors

KeyboardTheme(BuildContext context, {EdgeInsets? keyPadding, Color? backgroundColor, double? borderWidth, Color? borderColor, Color? textColor, TextStyle? textStyle})

Properties

backgroundColor Color?
final
borderColor Color
final
borderWidth double
final
hashCode int
The hash code for this object.
no setterinherited
keyPadding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color
final
textStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited